#ifndef ROMINFO_H
#define ROMINFO_H

#include <QString>
#include <QStringList>

class RomInfo
{
public:
    RomInfo();

    QString DisplayName;
    QString FilePath;
    QString FileName;
    QStringList SaveStateNames;

    bool IsMultiDisc() { return SaveStateNames.count() > 1; }
};

#endif // ROMINFO_H
